from distutils.core import setup
setup(
 name = 'dupl',
 version = '1.0.0',
 py_modules = ['dupl'],
 author = 'Akshat',
 author_email = 'akshatgarg789@gmail.com',
 description = 'removes duplicate items from your list',
)